import { memo, useCallback, useState, useEffect } from 'react';
import { Button } from '@/components/ui/button';
import { Check, MessageSquare } from 'lucide-react';
import { useIntersectionObserver } from '@/hooks/useIntersectionObserver';
import EnhancedOptimizedImage from '@/components/EnhancedOptimizedImage';

const BENEFITS = [
  "No Tax Returns Required",
  "Bank Statement Qualification",
  "Self-Employed Friendly",
  "Investment Property Loans",
  "Fast 10-Day Closings",
  "Competitive Rates Available"
];

const BenefitItem = memo(({ benefit, index }: { benefit: string; index: number }) => (
  <div 
    className="flex items-center space-x-2 group mobile-benefit-item"
    style={{ animationDelay: `${index * 50}ms` }}
  >
    <div className="bg-green-100 rounded-full p-1 flex-shrink-0">
      <Check className="w-3 h-3 text-green-600" />
    </div>
    <span className="text-sm text-gray-700 group-hover:text-gray-900 transition-colors">
      {benefit}
    </span>
  </div>
));

BenefitItem.displayName = 'BenefitItem';

// Lightweight placeholder for iframe until user interaction
const WidgetPlaceholder = memo(({ onLoad }: { onLoad: () => void }) => (
  <div className="bg-white p-6 rounded-lg shadow-lg border border-gray-200">
    <div className="text-center">
      <h3 className="text-lg font-bold text-gray-900 mb-4">Get Your Mortgage Quote</h3>
      <p className="text-gray-600 mb-4">Quick qualification check for self-employed borrowers</p>
      <Button
        onClick={onLoad}
        className="bg-edition-orange hover:bg-edition-orange/90 text-white font-bold w-full"
      >
        Start Application
      </Button>
    </div>
  </div>
));

WidgetPlaceholder.displayName = 'WidgetPlaceholder';

const MobileOptimizedHero = () => {
  const [widgetLoaded, setWidgetLoaded] = useState(false);
  const { elementRef, isVisible } = useIntersectionObserver({
    threshold: 0.1,
    rootMargin: '50px'
  });

  const scrollToContact = useCallback(() => {
    const element = document.getElementById('contact');
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
  }, []);

  const scrollToSection = useCallback((sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
  }, []);

  const openChatWidget = useCallback(() => {
    // Dispatch custom event to trigger chat widget
    const event = new CustomEvent('openChatWidget');
    window.dispatchEvent(event);
  }, []);

  const loadWidget = useCallback(() => {
    setWidgetLoaded(true);
  }, []);

  // Load widget iframe only when needed
  useEffect(() => {
    if (widgetLoaded) {
      const container = document.getElementById('zero-income-widget');
      if (!container || container.querySelector('iframe')) return;

      const iframe = document.createElement('iframe');
      iframe.src = 'https://orange-interview-lead-flow.lovable.app/widget';
      iframe.style.width = '100%';
      iframe.style.height = '350px';
      iframe.style.border = 'none';
      iframe.style.borderRadius = '0';
      iframe.style.maxWidth = '100%';
      iframe.setAttribute('allowtransparency', 'true');
      
      container.appendChild(iframe);
      
      // Auto-resize based on content
      const handleMessage = (event: MessageEvent) => {
        if (event.data.type === 'ZIM_WIDGET_RESIZE') {
          iframe.style.height = event.data.height + 'px';
        }
      };
      
      window.addEventListener('message', handleMessage);
    }
  }, [widgetLoaded]);

  return (
    <section 
      ref={elementRef}
      className="relative bg-gradient-to-br from-slate-50 to-gray-100 lg:min-h-[80vh] py-8 lg:py-16 mobile-hero-section"
      aria-label="Zero Income Mortgage Hero Section"
    >
      <div className="container mx-auto px-4 lg:px-6">
        <div className="lg:grid lg:grid-cols-2 lg:gap-12 lg:items-center">
          
          {/* Content Section - Mobile First */}
          <div className="mb-8 lg:mb-0 lg:order-1">
            <h1 className="text-3xl lg:text-5xl font-bold text-brand-charcoal mb-4 lg:mb-6 leading-tight">
              <span className="block">Get Approved</span>
              <span className="block text-edition-orange">Without Tax Returns</span>
            </h1>
            
            <p className="text-lg lg:text-xl text-gray-600 mb-6 lg:mb-8 leading-relaxed">
              Specialized in <strong>bank statement loans</strong>, <strong>DSCR loans</strong>, and 
              <strong> no-doc mortgages</strong> for self-employed borrowers and real estate investors.
            </p>

            {/* Benefits Grid - Optimized for mobile */}
            <div className="grid grid-cols-1 sm:grid-cols-2 gap-3 mb-6 lg:mb-8">
              {BENEFITS.map((benefit, index) => (
                <BenefitItem key={benefit} benefit={benefit} index={index} />
              ))}
            </div>

            {/* CTA Buttons */}
            <div className="flex flex-col sm:flex-row gap-3 mb-6">
              <Button 
                onClick={scrollToContact}
                className="bg-edition-orange hover:bg-edition-orange/90 text-white font-bold text-lg px-6 py-3 flex-1 sm:flex-none"
                aria-label="Submit your mortgage scenario for review"
              >
                Submit Your Scenario
              </Button>
              
              <Button 
                variant="outline"
                onClick={openChatWidget}
                className="border-edition-orange text-edition-orange hover:bg-edition-orange hover:text-white font-semibold text-lg px-6 py-3 flex-1 sm:flex-none"
                aria-label="Chat with our AI mortgage assistant"
              >
                <MessageSquare className="w-5 h-5 mr-2" />
                Chat with AI Agent
              </Button>
            </div>

            {/* Internal Links for SEO */}
            <div className="text-sm text-gray-500 space-y-1">
              <p>
                Explore: 
                <button 
                  onClick={() => scrollToSection('loan-programs')} 
                  className="text-edition-orange hover:underline ml-1"
                >
                  Loan Programs
                </button>
                {" • "}
                <button 
                  onClick={() => scrollToSection('mortgage-calculator')} 
                  className="text-edition-orange hover:underline"
                >
                  Calculator
                </button>
                {" • "}
                <button 
                  onClick={() => scrollToSection('resources')} 
                  className="text-edition-orange hover:underline"
                >
                  Resources
                </button>
              </p>
            </div>
          </div>

          {/* Lead Form Section - Deferred Loading */}
          <div className="lg:order-2">
            <div className="max-w-md mx-auto lg:max-w-none">
              <div className="bg-white rounded-xl shadow-xl border-2 border-edition-orange/20 overflow-hidden">
                <div className="p-4 lg:p-6 pb-4">
                  <h3 className="font-bold text-brand-charcoal mb-2 lg:mb-4 text-center text-lg lg:text-xl">
                    Schedule Your Non-QM Consultation
                  </h3>
                  <p className="text-brand-charcoal mb-0 text-center text-sm lg:text-base">
                    Book a free 30-minute strategy call with our non-QM specialists
                  </p>
                </div>
                
                {!widgetLoaded ? (
                  <WidgetPlaceholder onLoad={loadWidget} />
                ) : (
                  <div 
                    id="zero-income-widget" 
                    className="w-full h-[350px]"
                    style={{
                      contain: 'layout style paint'
                    }}
                  >
                    {/* Widget iframe loads here after user interaction */}
                  </div>
                )}
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Background decoration - Only load when visible */}
      {isVisible && (
        <div className="absolute inset-0 overflow-hidden pointer-events-none">
          <div className="absolute -top-40 -right-40 w-80 h-80 bg-edition-orange/5 rounded-full blur-3xl"></div>
          <div className="absolute -bottom-40 -left-40 w-80 h-80 bg-blue-500/5 rounded-full blur-3xl"></div>
        </div>
      )}
    </section>
  );
};

export default memo(MobileOptimizedHero);